@@ -156,7 +156,11 @@ class CRM_Contact_Form_DedupeRules extends CRM_Admin_Form {
       }
     }
     if (empty($fields['threshold'])) {
-      $errors['threshold'] = ts('Threshold weight cannot be empty or zero.');
+      // CRM-20607 - Don't validate the threshold of hard-coded rules
+      if (!(CRM_Utils_Array::value('is_reserved', $fields) &&
+        CRM_Utils_File::isIncludable("CRM/Dedupe/BAO/QueryBuilder/{$self->_defaultValues['name']}.php"))) {
+        $errors['threshold'] = ts('Threshold weight cannot be empty or zero.');
+      }
     }
 
     if (!$fieldSelected) {
