@@ -1032,6 +1032,22 @@ FROM   civicrm_domain
     return $result;
   }
 
+  /**
+   * Returns a singular value.
+   *
+   * @return mixed|NULL
+   */
+  public function fetchValue() {
+    $result = $this->getDatabaseResult();
+    $row = $result->fetchRow();
+    $ret = NULL;
+    if ($row) {
+      $ret = $row[0];
+    }
+    $this->free();
+    return $ret;
+  }
+
   /**
    * Get all the result records as mapping between columns.
    *
