@@ -3,7 +3,7 @@
  +--------------------------------------------------------------------+
  | CiviCRM version 4.7                                                |
  +--------------------------------------------------------------------+
- | Copyright CiviCRM LLC (c) 2004-2016                                |
+ | Copyright CiviCRM LLC (c) 2004-2017                                |
  +--------------------------------------------------------------------+
  | This file is a part of CiviCRM.                                    |
  |                                                                    |
@@ -28,7 +28,7 @@
 /**
  *
  * @package CRM
- * @copyright CiviCRM LLC (c) 2004-2016
+ * @copyright CiviCRM LLC (c) 2004-2017
  */
 class CRM_Report_Form_Contribute_Bookkeeping extends CRM_Report_Form {
   protected $_addressField = FALSE;
@@ -173,12 +173,22 @@ class CRM_Report_Form_Contribute_Bookkeeping extends CRM_Report_Form {
             'alias' => 'financial_account_civireport_debit',
             'default' => TRUE,
           ),
+          'debit_contact_id' => array(
+            'title' => ts('Financial Account Owner - Debit'),
+            'name' => 'organization_name',
+            'alias' => 'debit_contact',
+          ),
           'credit_accounting_code' => array(
             'title' => ts('Financial Account Code - Credit'),
             'name' => 'accounting_code',
             'alias' => 'financial_account_civireport_credit',
             'default' => TRUE,
           ),
+          'credit_contact_id' => array(
+            'title' => ts('Financial Account Owner - Credit'),
+            'name' => 'organization_name',
+            'alias' => 'credit_contact',
+          ),
           'debit_name' => array(
             'title' => ts('Financial Account Name - Debit'),
             'name' => 'name',
@@ -200,11 +210,29 @@ class CRM_Report_Form_Contribute_Bookkeeping extends CRM_Report_Form {
             'name' => 'accounting_code',
             'alias' => 'financial_account_civireport_debit',
           ),
+          'debit_contact_id' => array(
+            'title' => ts('Financial Account Owner - Debit'),
+            'operatorType' => CRM_Report_Form::OP_SELECT,
+            'type' => CRM_Utils_Type::T_INT,
+            'options' => array('' => '- Select Organization -') + CRM_Financial_BAO_FinancialAccount::getOrganizationNames(),
+            'name' => 'contact_id',
+            'alias' => 'financial_account_civireport_debit',
+          ),
           'credit_accounting_code' => array(
             'title' => ts('Financial Account Code - Credit'),
             'type' => CRM_Utils_Type::T_INT,
             'operatorType' => CRM_Report_Form::OP_MULTISELECT,
             'options' => CRM_Contribute_PseudoConstant::financialAccount(NULL, NULL, 'accounting_code', 'accounting_code'),
+            'name' => 'accounting_code',
+            'alias' => 'financial_account_civireport_credit',
+          ),
+          'credit_contact_id' => array(
+            'title' => ts('Financial Account Owner - Credit'),
+            'operatorType' => CRM_Report_Form::OP_SELECT,
+            'type' => CRM_Utils_Type::T_INT,
+            'options' => array('' => '- Select Organization -') + CRM_Financial_BAO_FinancialAccount::getOrganizationNames(),
+            'name' => 'contact_id',
+            'alias' => 'financial_account_civireport_credit',
           ),
           'debit_name' => array(
             'title' => ts('Financial Account Name - Debit'),
@@ -219,6 +247,8 @@ class CRM_Report_Form_Contribute_Bookkeeping extends CRM_Report_Form {
             'type' => CRM_Utils_Type::T_STRING,
             'operatorType' => CRM_Report_Form::OP_MULTISELECT,
             'options' => CRM_Contribute_PseudoConstant::financialAccount(),
+            'name' => 'id',
+            'alias' => 'financial_account_civireport_credit',
           ),
         ),
       ),
@@ -272,11 +302,17 @@ class CRM_Report_Form_Contribute_Bookkeeping extends CRM_Report_Form {
             'default' => TRUE,
           ),
           'id' => array(
-            'title' => ts('Contribution #'),
+            'title' => ts('Contribution ID'),
             'default' => TRUE,
           ),
         ),
         'filters' => array(
+          'contribution_id' => array(
+            'title' => ts('Contribution ID'),
+            'name' => 'id',
+            'operatorType' => CRM_Report_Form::OP_INT,
+            'type' => CRM_Utils_Type::T_INT,
+          ),
           'receive_date' => array('operatorType' => CRM_Report_Form::OP_DATE),
           'contribution_status_id' => array(
             'title' => ts('Contribution Status'),
@@ -315,6 +351,9 @@ class CRM_Report_Form_Contribute_Bookkeeping extends CRM_Report_Form {
             'title' => ts('Trans #'),
             'default' => TRUE,
           ),
+          'card_type_id' => array(
+            'title' => ts('Credit Card Type'),
+          ),
         ),
         'filters' => array(
           'payment_instrument_id' => array(
@@ -335,6 +374,19 @@ class CRM_Report_Form_Contribute_Bookkeeping extends CRM_Report_Form {
             'operatorType' => CRM_Report_Form::OP_DATE,
             'type' => CRM_Utils_Type::T_DATE,
           ),
+          'status_id' => array(
+            'title' => ts('Financial Transaction Status'),
+            'operatorType' => CRM_Report_Form::OP_MULTISELECT,
+            'options' => CRM_Contribute_PseudoConstant::contributionStatus(),
+            'default' => array(1),
+          ),
+          'card_type_id' => array(
+            'title' => ts('Credit Card Type'),
+            'operatorType' => CRM_Report_Form::OP_MULTISELECT,
+            'options' => CRM_Financial_DAO_FinancialTrxn::buildOptions('card_type_id'),
+            'default' => NULL,
+            'type' => CRM_Utils_Type::T_STRING,
+          ),
         ),
         'order_bys' => array(
           'payment_instrument_id' => array('title' => ts('Payment Method')),
@@ -376,11 +428,12 @@ class CRM_Report_Form_Contribute_Bookkeeping extends CRM_Report_Form {
           ) {
             switch ($fieldName) {
               case 'credit_accounting_code':
+              case 'credit_name':
                 $select[] = " CASE
                             WHEN {$this->_aliases['civicrm_financial_trxn']}.from_financial_account_id IS NOT NULL
-                            THEN  {$this->_aliases['civicrm_financial_account']}_credit_1.accounting_code
-                            ELSE  {$this->_aliases['civicrm_financial_account']}_credit_2.accounting_code
-                            END AS civicrm_financial_account_credit_accounting_code ";
+                            THEN  {$this->_aliases['civicrm_financial_account']}_credit_1.{$field['name']}
+                            ELSE  {$this->_aliases['civicrm_financial_account']}_credit_2.{$field['name']}
+                            END AS civicrm_financial_account_{$fieldName} ";
                 break;
 
               case 'amount':
@@ -391,12 +444,12 @@ class CRM_Report_Form_Contribute_Bookkeeping extends CRM_Report_Form {
                             END AS civicrm_entity_financial_trxn_amount ";
                 break;
 
-              case 'credit_name':
+              case 'credit_contact_id':
                 $select[] = " CASE
                             WHEN {$this->_aliases['civicrm_financial_trxn']}.from_financial_account_id IS NOT NULL
-                            THEN  {$this->_aliases['civicrm_financial_account']}_credit_1.name
-                            ELSE  {$this->_aliases['civicrm_financial_account']}_credit_2.name
-                            END AS civicrm_financial_account_credit_name ";
+                            THEN  credit_contact_1.{$field['name']}
+                            ELSE  credit_contact_2.{$field['name']}
+                            END AS civicrm_financial_account_{$fieldName} ";
                 break;
 
               default:
@@ -432,8 +485,10 @@ class CRM_Report_Form_Contribute_Bookkeeping extends CRM_Report_Form {
                     ON {$this->_aliases['civicrm_financial_trxn']}.id = {$this->_aliases['civicrm_entity_financial_trxn']}.financial_trxn_id
               LEFT JOIN civicrm_financial_account {$this->_aliases['civicrm_financial_account']}_debit
                     ON {$this->_aliases['civicrm_financial_trxn']}.to_financial_account_id = {$this->_aliases['civicrm_financial_account']}_debit.id
+              LEFT JOIN civicrm_contact debit_contact ON {$this->_aliases['civicrm_financial_account']}_debit.contact_id = debit_contact.id
               LEFT JOIN civicrm_financial_account {$this->_aliases['civicrm_financial_account']}_credit_1
                     ON {$this->_aliases['civicrm_financial_trxn']}.from_financial_account_id = {$this->_aliases['civicrm_financial_account']}_credit_1.id
+              LEFT JOIN civicrm_contact credit_contact_1 ON {$this->_aliases['civicrm_financial_account']}_credit_1.contact_id = credit_contact_1.id
               LEFT JOIN civicrm_entity_financial_trxn {$this->_aliases['civicrm_entity_financial_trxn']}_item
                     ON ({$this->_aliases['civicrm_financial_trxn']}.id = {$this->_aliases['civicrm_entity_financial_trxn']}_item.financial_trxn_id AND
                         {$this->_aliases['civicrm_entity_financial_trxn']}_item.entity_table = 'civicrm_financial_item')
@@ -441,8 +496,11 @@ class CRM_Report_Form_Contribute_Bookkeeping extends CRM_Report_Form {
                     ON fitem.id = {$this->_aliases['civicrm_entity_financial_trxn']}_item.entity_id
               LEFT JOIN civicrm_financial_account {$this->_aliases['civicrm_financial_account']}_credit_2
                     ON fitem.financial_account_id = {$this->_aliases['civicrm_financial_account']}_credit_2.id
+              LEFT JOIN civicrm_contact credit_contact_2 ON {$this->_aliases['civicrm_financial_account']}_credit_2.contact_id = credit_contact_2.id
               LEFT JOIN civicrm_line_item {$this->_aliases['civicrm_line_item']}
-                    ON  fitem.entity_id = {$this->_aliases['civicrm_line_item']}.id AND fitem.entity_table = 'civicrm_line_item' ";
+                    ON  fitem.entity_id = {$this->_aliases['civicrm_line_item']}.id AND fitem.entity_table = 'civicrm_line_item'
+              ";
+
     if ($this->isTableSelected('civicrm_batch')) {
       $this->_from .= "LEFT JOIN civicrm_entity_batch ent_batch
                     ON  {$this->_aliases['civicrm_financial_trxn']}.id = ent_batch.entity_id AND ent_batch.entity_table = 'civicrm_financial_trxn'
@@ -472,18 +530,16 @@ class CRM_Report_Form_Contribute_Bookkeeping extends CRM_Report_Form {
       if (array_key_exists('filters', $table)) {
         foreach ($table['filters'] as $fieldName => $field) {
           $clause = NULL;
-          if ($fieldName == 'credit_accounting_code') {
+          if (in_array($fieldName, array(
+               'credit_accounting_code',
+               'credit_name',
+               'credit_contact_id',
+             )
+          )) {
             $field['dbAlias'] = "CASE
               WHEN financial_trxn_civireport.from_financial_account_id IS NOT NULL
-              THEN  financial_account_civireport_credit_1.accounting_code
-              ELSE  financial_account_civireport_credit_2.accounting_code
-              END";
-          }
-          elseif ($fieldName == 'credit_name') {
-            $field['dbAlias'] = "CASE
-              WHEN financial_trxn_civireport.from_financial_account_id IS NOT NULL
-              THEN  financial_account_civireport_credit_1.id
-              ELSE  financial_account_civireport_credit_2.id
+              THEN  financial_account_civireport_credit_1.{$field['name']}
+              ELSE  financial_account_civireport_credit_2.{$field['name']}
               END";
           }
           if (CRM_Utils_Array::value('type', $field) & CRM_Utils_Type::T_DATE) {
@@ -555,7 +611,7 @@ class CRM_Report_Form_Contribute_Bookkeeping extends CRM_Report_Form {
 
     $this->groupBy();
 
-    $tempQuery = "CREATE TEMPORARY TABLE {$tempTableName} CHARACTER SET utf8 COLLATE utf8_unicode_ci AS
+    $tempQuery = "CREATE TEMPORARY TABLE {$tempTableName} {$this->_databaseAttributes} AS
                   {$select} {$this->_from} {$this->_where} {$this->_groupBy} ";
     CRM_Core_DAO::executeQuery($tempQuery);
 
@@ -596,6 +652,7 @@ class CRM_Report_Form_Contribute_Bookkeeping extends CRM_Report_Form {
     $contributionTypes = CRM_Contribute_PseudoConstant::financialType();
     $paymentInstruments = CRM_Contribute_PseudoConstant::paymentInstrument();
     $contributionStatus = CRM_Contribute_PseudoConstant::contributionStatus();
+    $creditCardTypes = CRM_Financial_DAO_FinancialTrxn::buildOptions('card_type_id');
     foreach ($rows as $rowNum => $row) {
       // convert display name to links
       if (array_key_exists('civicrm_contact_sort_name', $row) &&
@@ -637,6 +694,11 @@ class CRM_Report_Form_Contribute_Bookkeeping extends CRM_Report_Form {
         $entryFound = TRUE;
       }
 
+      if (!empty($row['civicrm_financial_trxn_card_type_id'])) {
+        $rows[$rowNum]['civicrm_financial_trxn_card_type_id'] = CRM_Utils_Array::value($row['civicrm_financial_trxn_card_type_id'], $creditCardTypes);
+        $entryFound = TRUE;
+      }
+
       // display birthday in the configured custom format
       if (array_key_exists('civicrm_contact_birth_date', $row)) {
         $birthDate = $row['civicrm_contact_birth_date'];
