@@ -130,7 +130,7 @@ class CRM_Report_Page_InstanceList extends CRM_Core_Page {
 
           WHERE v.is_active = 1 {$report}
                 AND inst.domain_id = %1
-          ORDER BY  v.weight";
+          ORDER BY  v.weight ASC, inst.title ASC";
 
     $dao = CRM_Core_DAO::executeQuery($sql, array(
       1 => array(CRM_Core_Config::domainID(), 'Integer'),
