@@ -3,7 +3,7 @@
  +--------------------------------------------------------------------+
  | CiviCRM version 4.7                                                |
  +--------------------------------------------------------------------+
- | Copyright CiviCRM LLC (c) 2004-2016                                |
+ | Copyright CiviCRM LLC (c) 2004-2017                                |
  +--------------------------------------------------------------------+
  | This file is a part of CiviCRM.                                    |
  |                                                                    |
@@ -113,18 +113,10 @@ function civicrm_api3_setting_getdefaults(&$params) {
   $defaults = array();
   foreach ($domains as $domainID) {
     $defaults[$domainID] = array();
-    $noDefaults = array();
     foreach ($settings['values'] as $setting => $spec) {
       if (array_key_exists('default', $spec) && !is_null($spec['default'])) {
         $defaults[$domainID][$setting] = $spec['default'];
       }
-      else {
-        $noDefaults[$setting] = 1;
-      }
-    }
-    if (!empty($params['debug'])) {
-      // we are only tracking 'noDefaults' to help us check the xml
-      print_r($noDefaults);
     }
   }
   return civicrm_api3_create_success($defaults, $params, 'Setting', 'getfields');
@@ -354,7 +346,7 @@ function civicrm_api3_setting_getvalue($params) {
   //  return $config->$params['name'];
   //}
   return CRM_Core_BAO_Setting::getItem(
-    $params['group'],
+    NULL,
     CRM_Utils_Array::value('name', $params),
     CRM_Utils_Array::value('component_id', $params),
     CRM_Utils_Array::value('default_value', $params),
